@@ -36,7 +36,7 @@ deaths_df = get_n_melt_data(death_cases_url, "Deaths")
 @click.group(
     cls=HelpColorsGroup, help_headers_color="yellow", help_options_color="cyan"
 )
-@click.version_option("0.1.1", prog_name="covidcli")
+@click.version_option("0.1.3", prog_name="covidcli")
 def main():
     """Covid-cli : A simple CLI for Getting info about Coronavirus Outbreak"""
     pass
@@ -68,7 +68,7 @@ def show(cases):
 
 @main.group()
 def get():
-    """Get Info about Latest|Previous|Status|dataset"""
+    """Get Info of cases by latest|previous|status|dataset"""
     pass
 
 
@@ -226,7 +226,7 @@ def search(countryname, cases):
     elif cases == "latest":
         current_df = merge_data(confirm_df, recovered_df, deaths_df)
         current_country_df = current_df[current_df["Country/Region"] == countryname]
-        click.echo("Showing Previous Data")
+        click.echo("Showing Latest Data")
         click.echo(current_country_df)
     else:
         click.echo(country_df)
